@@ -86,6 +86,7 @@ def deliver_prompts(
     chunk_size: int = 2000,
     extra_chunk_info_fn: Callable[['Document'], str] = lambda doc: '',
     dry_run: bool = False,
+    parts: list[int] | None = None,
 ):
     from langchain.prompts import PromptTemplate
 
@@ -125,6 +126,7 @@ def deliver_prompts(
         if edit:
             print(f'Please copy the prompts after each edits.', file=sys.stderr)
         for i, doc in enumerate(documents):
+            num_chunks = len(documents)
             if i == 0:
                 prompt = PromptTemplate.from_template(
                     REPLY_OK_IF_YOU_READ_TEMPLATE_SPLITTED_FIRST
@@ -158,7 +160,7 @@ def deliver_prompts(
 
     if dry_run:
         print(
-            f'Dry running. Nothing will be copied to your clipboard, and you don'
+            f'Dry running. Nothing will be copied to your clipboard, and you don\''
             't need to press Enter to move forward.'
         )
     if needs_splitting:
@@ -166,7 +168,14 @@ def deliver_prompts(
 
         splitter = TokenTextSplitter(encoding_name='cl100k_base', chunk_size=chunk_size)
         splitted = splitter.split_documents(documents)
-        num_chunks = len(splitted)
+        if parts:
+            len_splitted = len(splitted)
+            parts = list({part for part in parts if 0 <= part - 1 < len_splitted})
+            print(
+                f'Selecting {len(parts)} parts out of {len_splitted}.', file=sys.stderr
+            )
+            print(f'Using parts: {parts}', file=sys.stderr)
+            splitted = [splitted[i - 1] for i in parts]
         deliver_multiple_docs(splitted)
 
     elif should_be_only_one_doc:
